[![CI](https://github.com/ovirt/ovirt-ansible-collection/actions/workflows/build.yaml/badge.svg?branch=master)](https://github.com/oVirt/ovirt-ansible-collection/actions/workflows/build.yaml)
[![Copr build status](https://copr.fedorainfracloud.org/coprs/ovirt/ovirt-master-snapshot/package/ovirt-ansible-collection/status_image/last_build.png)](https://copr.fedorainfracloud.org/coprs/ovirt/ovirt-master-snapshot/package/ovirt-ansible-collection/)
[![Build Status](https://img.shields.io/badge/docs-latest-blue.svg)](https://docs.ansible.com/ansible/2.10/collections/ovirt/ovirt/index.html)

oVirt Ansible Collection
====================================

Requirements
------------

 * Ansible core version 2.12.0 or higher
 * Python SDK version 4.5.0 or higher

Upstream oVirt documentation
--------------
https://docs.ansible.com/ansible/latest/collections/ovirt/ovirt/index.html

Downstream RHV documentation
--------------
https://cloud.redhat.com/ansible/automation-hub/redhat/rhv


Licenses
-------

- Apache License 2.0
- GNU General Public License 3.0
